summaryrefslogtreecommitdiffstats
path: root/korn
diff options
context:
space:
mode:
Diffstat (limited to 'korn')
-rw-r--r--korn/boxcontaineritem.cpp12
-rw-r--r--korn/boxcontaineritem.h14
-rw-r--r--korn/dockeditem.cpp2
-rw-r--r--korn/dockeditem.h2
-rw-r--r--korn/hvitem.cpp6
-rw-r--r--korn/hvitem.h8
-rw-r--r--korn/kornboxcfgimpl.cpp4
-rw-r--r--korn/subjectsdlg.cpp6
-rw-r--r--korn/subjectsdlg.h6
9 files changed, 30 insertions, 30 deletions
diff --git a/korn/boxcontaineritem.cpp b/korn/boxcontaineritem.cpp
index 50daf1d0..ad4c40bd 100644
--- a/korn/boxcontaineritem.cpp
+++ b/korn/boxcontaineritem.cpp
@@ -192,7 +192,7 @@ void BoxContainerItem::mouseButtonPressed( TQt::ButtonState state )
doPopup();
}
-void BoxContainerItem::fillKPopupMenu( KPopupMenu* popupMenu, KActionCollection* actions ) const
+void BoxContainerItem::fillTDEPopupMenu( TDEPopupMenu* popupMenu, TDEActionCollection* actions ) const
{
/*popupMenu->insertItem( i18n( "&Configure" ), this, TQT_SLOT( slotConfigure() ) );
popupMenu->insertItem( i18n( "&Recheck" ), this, TQT_SLOT( slotRecheck() ) );
@@ -200,11 +200,11 @@ void BoxContainerItem::fillKPopupMenu( KPopupMenu* popupMenu, KActionCollection*
popupMenu->insertItem( i18n( "&View Emails" ), this, TQT_SLOT( slotView() ) );
popupMenu->insertItem( i18n( "R&un Command" ), this, TQT_SLOT( slotRunCommand() ) );*/
- (new KAction( i18n("&Configure"), KShortcut(), this, TQT_SLOT( slotConfigure() ), actions ))->plug( popupMenu );
- (new KAction( i18n("&Recheck"), KShortcut(), this, TQT_SLOT( slotRecheck() ), actions ))->plug( popupMenu );
- (new KAction( i18n("R&eset Counter"), KShortcut(), this, TQT_SLOT( slotReset() ), actions ))->plug( popupMenu );
- (new KAction( i18n("&View Emails"), KShortcut(), this, TQT_SLOT( slotView() ), actions ))->plug( popupMenu );
- (new KAction( i18n("R&un Command"), KShortcut(), this, TQT_SLOT( slotRunCommand() ), actions ))->plug( popupMenu );
+ (new TDEAction( i18n("&Configure"), TDEShortcut(), this, TQT_SLOT( slotConfigure() ), actions ))->plug( popupMenu );
+ (new TDEAction( i18n("&Recheck"), TDEShortcut(), this, TQT_SLOT( slotRecheck() ), actions ))->plug( popupMenu );
+ (new TDEAction( i18n("R&eset Counter"), TDEShortcut(), this, TQT_SLOT( slotReset() ), actions ))->plug( popupMenu );
+ (new TDEAction( i18n("&View Emails"), TDEShortcut(), this, TQT_SLOT( slotView() ), actions ))->plug( popupMenu );
+ (new TDEAction( i18n("R&un Command"), TDEShortcut(), this, TQT_SLOT( slotRunCommand() ), actions ))->plug( popupMenu );
popupMenu->insertSeparator();
KStdAction::help( this, TQT_SLOT( help() ), actions )->plug( popupMenu );
KStdAction::reportBug( this, TQT_SLOT( reportBug() ), actions )->plug( popupMenu );
diff --git a/korn/dockeditem.cpp b/korn/dockeditem.cpp
index 474ffb28..7e2b53a8 100644
--- a/korn/dockeditem.cpp
+++ b/korn/dockeditem.cpp
@@ -40,7 +40,7 @@ DockedItem::DockedItem( TQWidget * parent, const char * name )
: BoxContainerItem( TQT_TQOBJECT(parent), name ),
_systemtray( new SystemTray( parent, "System tray" ) )
{
- this->fillKPopupMenu( _systemtray->contextMenu(), _systemtray->actionCollection() );
+ this->fillTDEPopupMenu( _systemtray->contextMenu(), _systemtray->actionCollection() );
connect( _systemtray, TQT_SIGNAL( quitSelected() ), kapp, TQT_SLOT( quit() ) );
connect( _systemtray, TQT_SIGNAL( mouseButtonPressed( TQt::ButtonState ) ),
diff --git a/korn/dockeditem.h b/korn/dockeditem.h
index e375bb97..46513c9c 100644
--- a/korn/dockeditem.h
+++ b/korn/dockeditem.h
@@ -83,7 +83,7 @@ public slots:
protected:
/**
- * This function popup's the KPopupMenu inmideately.
+ * This function popup's the TDEPopupMenu inmideately.
*/
virtual void doPopup();
diff --git a/korn/hvitem.cpp b/korn/hvitem.cpp
index d2453b64..fef3dbef 100644
--- a/korn/hvitem.cpp
+++ b/korn/hvitem.cpp
@@ -33,11 +33,11 @@
HVItem::HVItem( TQWidget *parent, const char *name )
: BoxContainerItem( 0, name ),
_label( new Label( parent, "label" ) ),
- _popup( new KPopupMenu( _label, "popupmenu" ) ),
- _actions( new KActionCollection( _popup, "actions" ) )
+ _popup( new TDEPopupMenu( _label, "popupmenu" ) ),
+ _actions( new TDEActionCollection( _popup, "actions" ) )
{
_popup->insertTitle( kapp->miniIcon(), kapp->caption() );
- this->fillKPopupMenu( _popup, _actions );
+ this->fillTDEPopupMenu( _popup, _actions );
_popup->insertSeparator();
KStdAction::quit( TQT_TQOBJECT(kapp), TQT_SLOT( quit() ), _actions )->plug( _popup );
diff --git a/korn/hvitem.h b/korn/hvitem.h
index 550d19ba..9e2045b1 100644
--- a/korn/hvitem.h
+++ b/korn/hvitem.h
@@ -21,8 +21,8 @@
#include <boxcontaineritem.h>
-class KActionCollection;
-class KPopupMenu;
+class TDEActionCollection;
+class TDEPopupMenu;
class Label;
@@ -74,8 +74,8 @@ public slots:
virtual void doPopup();
private:
Label *_label;
- KPopupMenu *_popup;
- KActionCollection *_actions;
+ TDEPopupMenu *_popup;
+ TDEActionCollection *_actions;
};
#endif //MK_HVITEM_H
diff --git a/korn/kornboxcfgimpl.cpp b/korn/kornboxcfgimpl.cpp
index f7904b59..785b94fb 100644
--- a/korn/kornboxcfgimpl.cpp
+++ b/korn/kornboxcfgimpl.cpp
@@ -301,7 +301,7 @@ void KornBoxCfgImpl::slotChangeNewAnim()
void KornBoxCfgImpl::slotChangeNormalFont()
{
- KFontDialog fd( this, "font dialog" );
+ TDEFontDialog fd( this, "font dialog" );
fd.setFont( *_fonts[ 0 ], false );
fd.exec();
*_fonts[ 0 ] = fd.font();
@@ -309,7 +309,7 @@ void KornBoxCfgImpl::slotChangeNormalFont()
void KornBoxCfgImpl::slotChangeNewFont()
{
- KFontDialog fd( this, "font dialog" );
+ TDEFontDialog fd( this, "font dialog" );
fd.setFont( *_fonts[ 1 ], false );
fd.exec();
*_fonts[ 1 ] = fd.font();
diff --git a/korn/subjectsdlg.cpp b/korn/subjectsdlg.cpp
index d1cf3954..6a2ec184 100644
--- a/korn/subjectsdlg.cpp
+++ b/korn/subjectsdlg.cpp
@@ -15,7 +15,7 @@
KornSubjectsDlg::SubjectListViewItem::SubjectListViewItem( TQListView *parent, KornMailSubject * item)
// set the column strings except column 2 (date)
- : KListViewItem(parent, item->getSender(), item->getSubject(), "", TDEGlobal::locale()->formatNumber(item->getSize(), 0))
+ : TDEListViewItem(parent, item->getSender(), item->getSubject(), "", TDEGlobal::locale()->formatNumber(item->getSize(), 0))
, _mailSubject( new KornMailSubject( *item ) )
{
// convert the date according to the user settings and show it in column 2
@@ -49,7 +49,7 @@ int KornSubjectsDlg::SubjectListViewItem::compare( TQListViewItem* item, int col
else
{
// otherwise call default handling (i.e. string compare)
- return KListViewItem::compare( item, column, ascending );
+ return TDEListViewItem::compare( item, column, ascending );
}
}
@@ -72,7 +72,7 @@ KornSubjectsDlg::KornSubjectsDlg( TQWidget *parent )
showButton->setEnabled(false);
TQVBoxLayout * topLayout = new TQVBoxLayout( page, 0, spacingHint() );
TQHBoxLayout * buttons = new TQHBoxLayout();
- _list = new KListView(page);
+ _list = new TDEListView(page);
topLayout->addWidget(_list, 10);
topLayout->addLayout(buttons, 0);
buttons->addWidget(invertSelButton, 0);
diff --git a/korn/subjectsdlg.h b/korn/subjectsdlg.h
index 224d6e78..189f1a70 100644
--- a/korn/subjectsdlg.h
+++ b/korn/subjectsdlg.h
@@ -9,7 +9,7 @@
class KMailDrop;
class KornMailSubject;
class KornMailId;
-class KListView;
+class TDEListView;
class KornMailDlg;
class TQProgressDialog;
class DoubleProgressDialog;
@@ -30,7 +30,7 @@ class KornSubjectsDlg: public KDialogBase
* SubjectListViewItem is a helper class representing one line in the list view.
* It stores the mail subject the line represents and controls the sorting.
*/
- class SubjectListViewItem : public KListViewItem
+ class SubjectListViewItem : public TDEListViewItem
{
KornMailSubject * _mailSubject;
public:
@@ -80,7 +80,7 @@ class KornSubjectsDlg: public KDialogBase
int totalNumberOfMessages;
} *_delete;
- KListView * _list;
+ TDEListView * _list;
KPushButton * invertSelButton;
KPushButton * clearSelButton;
KPushButton * deleteButton;
diff --git a/korn/boxcontaineritem.h b/korn/boxcontaineritem.h
index 8672e430..a132c59e 100644
--- a/korn/boxcontaineritem.h
+++ b/korn/boxcontaineritem.h
@@ -24,9 +24,9 @@
class KornMailSubject;
-class KActionCollection;
+class TDEActionCollection;
class TDEConfig;
-class KPopupMenu;
+class TDEPopupMenu;
class TDEProcess;
class TQColor;
@@ -112,14 +112,14 @@ public slots:
void mouseButtonPressed( TQt::ButtonState button );
protected:
/**
* This function filles a KPopupMenu-reference. The target is
* to set in all implementations the same KPopupMenu-content.
* Because some implementations (TQt::DockedItem) got a KPopupMenu
* by itself, this only changes a KPopupMenu instance.
* @param menu The menu to be changed.
* @param actions The actions to which the items should be added.
*/
- void fillKPopupMenu( KPopupMenu* menu, KActionCollection* actions ) const;
+ void fillTDEPopupMenu( TDEPopupMenu* menu, TDEActionCollection* actions ) const;
/**
* This displays the passive popup.
@@ -112,14 +112,14 @@ public slots:
protected:
/**
- * This function filles a KPopupMenu-reference. The target is
- * to set in all implementations the same KPopupMenu-content.
- * Because some implementations (TQt::DockedItem) got a KPopupMenu
- * by itself, this only changes a KPopupMenu instance.
+ * This function filles a TDEPopupMenu-reference. The target is
+ * to set in all implementations the same TDEPopupMenu-content.
+ * Because some implementations (TQt::DockedItem) got a TDEPopupMenu
+ * by itself, this only changes a TDEPopupMenu instance.
* @param menu The menu to be changed.
* @param actions The actions to which the items should be added.